@@ -222,7 +222,7 @@ GO
 
 ALTER TABLE [dbo].[cache] ADD 
 	CONSTRAINT [DF_cache_user_id] DEFAULT ('0') FOR [user_id],
-	CONSTRAINT [DF_cache_cache_key] DEFAULT ('') FOR [cache_key],
+	CONSTRAINT [DF_cache_cache_key] DEFAULT ('') FOR [cache_key]
 GO
 
 ALTER TABLE [dbo].[cache_index] ADD 
