@@ -56,6 +56,8 @@ tinymce.addI18n('ar',{
 "OR": "\u0623\u0648",
 "Drop an image here": "\u0627\u0633\u0642\u0637 \u0627\u0644\u0635\u0648\u0631\u0629 \u0647\u0646\u0627",
 "Upload": "\u0631\u0641\u0639",
+"Block": "\u0642\u0633\u0645",
+"Align": "\u0645\u062d\u0627\u0630\u0627\u0629 \u0623\u0641\u0642\u064a\u0629",
 "Default": "\u0627\u0644\u0627\u0641\u062a\u0631\u0627\u0636\u064a",
 "Circle": "\u062f\u0627\u0626\u0631\u0629",
 "Disc": "\u0642\u0631\u0635",
@@ -75,6 +77,7 @@ tinymce.addI18n('ar',{
 "Source code": "\u0634\u0641\u0631\u0629 \u0627\u0644\u0645\u0635\u062f\u0631",
 "Insert\/Edit code sample": "\u0625\u062f\u0631\u0627\u062c\/\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0643\u0648\u062f",
 "Language": "\u0627\u0644\u0644\u063a\u0629",
+"Code sample": "\u0639\u064a\u0651\u0646\u0629 \u0639\u0646 \u0627\u0644\u0643\u0648\u062f \u0627\u0644\u0628\u0631\u0645\u062c\u064a",
 "Color": "\u0627\u0644\u0644\u0648\u0646",
 "R": "R",
 "G": "G",
@@ -105,6 +108,8 @@ tinymce.addI18n('ar',{
 "Premium plugins:": "\u0627\u0644\u0625\u0636\u0627\u0641\u0627\u062a \u0627\u0644\u0645\u0645\u064a\u0632\u0629:",
 "Learn more...": "\u0645\u0639\u0631\u0641\u0629 \u0627\u0644\u0645\u0632\u064a\u062f...",
 "You are using {0}": "\u0623\u0646\u062a \u062a\u0633\u062a\u062e\u062f\u0645 {0}",
+"Plugins": "\u0627\u0644\u0625\u0636\u0627\u0641\u0627\u062a",
+"Handy Shortcuts": "\u0627\u062e\u062a\u0635\u0627\u0631\u0627\u062a \u0645\u0633\u0627\u0639\u0650\u062f\u0629",
 "Horizontal line": "\u062e\u0637 \u0623\u0641\u0642\u064a",
 "Insert\/edit image": "\u0625\u062f\u0631\u0627\u062c\/\u062a\u062d\u0631\u064a\u0631 \u0635\u0648\u0631\u0629",
 "Image description": "\u0648\u0635\u0641 \u0627\u0644\u0635\u0648\u0631\u0629",
@@ -242,6 +247,7 @@ tinymce.addI18n('ar',{
 "Show blocks": "\u0645\u0634\u0627\u0647\u062f\u0629 \u0627\u0644\u0643\u062a\u0644",
 "Show invisible characters": "\u0623\u0638\u0647\u0631 \u0627\u0644\u0623\u062d\u0631\u0641 \u0627\u0644\u063a\u064a\u0631 \u0645\u0631\u0626\u064a\u0629",
 "Words: {0}": "\u0627\u0644\u0643\u0644\u0645\u0627\u062a:{0}",
+"{0} words": "{0} \u0643\u0644\u0645\u0627\u062a",
 "File": "\u0645\u0644\u0641",
 "Edit": "\u062a\u062d\u0631\u064a\u0631",
 "Insert": "\u0625\u062f\u0631\u0627\u062c",
@@ -249,6 +255,7 @@ tinymce.addI18n('ar',{
 "Format": "\u062a\u0646\u0633\u064a\u0642",
 "Table": "\u062c\u062f\u0648\u0644",
 "Tools": "\u0623\u062f\u0627\u0648\u0627\u062a",
+"Powered by {0}": "\u0645\u062f\u0639\u0648\u0645 \u0645\u0646 {0}",
 "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "\u0645\u0646\u0637\u0642\u0629 \u0646\u0635 \u0645\u0646\u0633\u0642. \u0627\u0636\u063a\u0637 ALT-F9 \u0644\u0644\u0642\u0627\u0626\u0645\u0629. \u0627\u0636\u063a\u0637 ALT-F10 \u0644\u0634\u0631\u064a\u0637 \u0627\u0644\u0623\u062f\u0648\u0627\u062a. \u0627\u0636\u063a\u0637 ALT-0 \u0644\u0644\u062d\u0635\u0648\u0644 \u0639\u0644\u0649 \u0645\u0633\u0627\u0639\u062f\u0629",
 "_dir": "rtl"
 });
\ No newline at end of file
